/*
 * (c) Copyright 1992-1995 North Valley Research, Inc.
 *      All Rights Reserved
 *
 * Confidential -- All proprietary rights reserved.
 * Licensed Material -- Property of North Valley Research, Inc.
 *
 * This program is the property of North Valley Research, Inc. or others
 * from whom North Valley Research has obtained a licensing right, and is
 * considered by North Valley Research to be confidential.  It is protected
 * by U.S. copyright law as an unpublished work and is
 * furnished pursuant to a written license agreement.  It may
 * not be used, copied or otherwise reproduced, or disclosed to
 * others except in accordance with the terms and conditions of
 * that agreement.
 *
 * NAME
 *      NvrMpegDisplay.h - public definitions for for nvr mpeg display widget
 *
 * $Header: /nvr/share/src/nvr/prod/library/motifUI/RCS/NvrMpegDisplay.h,v 1.3 1995/12/05 07:28:07 toddb Exp toddb $
 */

#ifndef _NvrMpegDisplay_h_
#define _NvrMpegDisplay_h_

#include <X11/Intrinsic.h>

/*
 * New resource definitions
 */

#define XnvrNAction		"nvrAction"
#define XnvrNAudioChannel	"nvrAudioChannel"
#define XnvrNAudioQuality	"nvrAudioQuality"
#define XnvrNAudioQualitySteps	"nvrAudioQualitySteps"
#define XnvrNBrightness		"nvrBrightness"
#define XnvrNContrast		"nvrContrast"
#define XnvrNDecodeWindow	"nvrDecodeWindow"
#define XnvrNDepth		"nvrDepth"
#define XnvrNDepths		"nvrDepths"
#define XnvrNInputFile		"nvrInputFile"
#define XnvrNSeekPoint		"nvrSeekPoint"
#define XnvrNState		"nvrState"
#define XnvrNSizeScale		"nvrSizeScale"
#define XnvrNVideoChannel	"nvrVideoChannel"
#define XnvrNVisual		"nvrVisual"
#define XnvrNStateCallback	"nvrStateCallback"

#define XnvrCAction		"NvrAction"
#define XnvrCAudioChannel	"NvrAudioChannel"
#define XnvrCAudioQuality	"NvrAudioQuality"
#define XnvrCAudioQualitySteps	"NvrAudioQualitySteps"
#define XnvrCBrightness		"NvrBrightness"
#define XnvrCContrast		"NvrContrast"
#define XnvrCDecodeWindow	"NvrDecodeWindow"
#define XnvrCDepth		"NvrDepth"
#define XnvrCDepths		"NvrDepths"
#define XnvrCInputFile		"NvrInputFile"
#define XnvrCSeekPoint		"NvrSeekPoint"
#define XnvrCState		"NvrState"
#define XnvrCSizeScale		"NvrSizeScale"
#define XnvrCVideoChannel	"NvrVideoChannel"
#define XnvrCVisual		"NvrVisual"
#define XnvrCStateCallback	"NvrStateCallback"

/*
 * Undocumented resource definitions
 */
#define XnvrNAlignWindow	"nvrAlignWindow"
#define XnvrNTrueColor12Bit	"nvrTrueColor12Bit"
#define XnvrNGamma		"nvrGamma"

#define XnvrCAlignWindow	"NvrAlignWindow"
#define XnvrCTrueColor12Bit	"NvrTrueColor12Bit"
#define XnvrCGamma		"NvrGamma"

/*
 * Special value for XnvrNAudioChannel and XnvrNVideoChannel
 */
enum { FirstAvailableChannel = -1 };

/*
 * XXX undocumented.  Range for gamma values
 */
typedef enum {
    NvrGammaHigh    = 300,
    NvrGammaLow     = 100,
    NvrDefaultGamma = 112,
    NvrGammaDivisor = 100,

    NvrDefaultContrast = 128,
    NvrDefaultBrightness = 128
} NvrGammaRange;

/*
 * These are the actions that can be set in the XnvrNAction resource
 */
typedef enum {
    NvrStop = 1,	/* force all actions to be non-zero */
    NvrPlayFwd,
    NvrPlayAll,
    NvrFastFwd,
    NvrPlayBak,
    NvrFastBak,
    NvrStepFwd,
    NvrStepBak
} NvrPlayerAction;

/*
 * These are the possible depth types specified with XnvrNDepth and
 * queried with XnvrNDepths.
 */
typedef enum {
    NvrRgb888  = 0x0001,
    NvrRgb444  = 0x0002,
    NvrRgb332  = 0x0004,
    NvrRgb232  = 0x0008,
    NvrGray8   = 0x0010,
    NvrGray7   = 0x0020,
    NvrRgbC555 = 0x0040,
    NvrRgbC666 = 0x0080
} NvrDepth;

/*
 * These are the possible size scalings that can be specified by
 * XnvrNSizeScale.
 */
typedef enum {
    NvrSize1x,
    NvrSize4x,
    NvrSizeQuarter
} NvrSizeScale;

/*
 * These are the bitmasks that describe value of the 'reason' element
 * in the structure below.
 */
typedef enum {
    NvrAudioChange  = 0x001,
    NvrEofReached   = 0x002,
    NvrFrameNumber  = 0x004,
    NvrNewPlayState = 0x008,
    NvrNewVideo     = 0x010,
    NvrNewAudio     = 0x020,
    NvrVideoChange  = 0x040
} NvrMpegDisplayCbReason;

/*
 * These are the possible values for the XnvrNState resource.
 */
typedef enum {
    NvrStopped = 0,		/* the default, initial state */
    NvrPlaying,
    NvrSeeking
} NvrPlayerState;

/*
 * This enum set and structure is used to describe the input file.
 */
typedef enum {
    NvrInputUnspecified = 0,	/* illegal */
    NvrInputSinglePath,		/* single pathname */
    NvrInputPathPair,		/* pair of pathnames: audio and video */
    NvrInputDescriptor,		/* file descriptor */
    NvrInputDescriptorPair,	/* file descriptor pair */
    NvrInputTcpPort		/* tcp port number for listening */
} NvrInputType;

typedef union _nvrInputSpec {
    NvrInputType type;
    struct {
	NvrInputType type;	/* must be NvrInputSinglePath */
	char *path;		/* audio, video or multiplexed file */
    } single;
    struct {
	NvrInputType type;	/* must be NvrInputPathPair */
	char *audio;		/* path to separate audio file */
	char *video;		/* path to separate video file */
    } pathPair;
    struct {
	NvrInputType type;	/* must be NvrTcpPort */
	char *host;		/* if specified, this host only; else any */
	int port;
    } net;
    struct {
	NvrInputType type;	/* must be NvrInputDescriptor */
	int fd;			/* file descriptor of open file */
    } descriptor;
    struct {
	NvrInputType type;	/* must be NvrInputDescriptorPair */
	int vfd;		/* file descriptor of video file */
	int afd;		/* file descriptor of audio file */
    } descriptorPair;
} NvrInputSpec, *NvrInputSpecPtr;

typedef union _nvrSeek {
    NvrInputType type;
    struct {
	NvrInputType type;	/* must be NvrInput{SinglePath,Descriptor} */
	long offset;
    } single;
    struct {
	NvrInputType type;	/* must be NvrInput{Path,Descriptor}Pair */
	long vOffset;		/* offset for video file */
	long aOffset;		/* offset for audio file */
    } pair;
} NvrSeek, *NvrSeekPtr;

/*
 * This is the structure of the third argument of the XtCallbackProc
 * specified for the XnvrNStateCallback resource.
 */
typedef struct {
    int cbMask;			/* mask of NvrMpegDisplayCbReason */
    NvrPlayerState playState;
    int frameNumber;		/* current frame number */
    long timeCode;		/* current time */
    long lastFrame;		/* last frame in sequence */
    Boolean lastApprox;		/* true: `lastFrame' is */
				/* only approximate */
    int width;			/* input width */
    int height;			/* input height */
    float frameRate;		/* video frame rate */
    int sampleRate;		/* audio output sample rate */
    int channels;		/* output channels 1=mono; 2=stereo */
} NvrMpegDisplayCbInfo, *NvrMpegDisplayCbInfoPtr;

/*
 * This is the structure of the third argument of the XtCallbackProc
 * specified for the XmNexposeCallback resource.
 */
typedef struct {
    int reason;			/* XmCR_EXPOSE, XmCR_INPUT or XmCR_RESIZE */
    XEvent *event;		/* event structure that triggered */
				/* the callback */
    Window window;		/* the widget's window */
} NvrMpegExposeCbInfo, *NvrMpegExposeCbInfoPtr;

extern WidgetClass xnvrMpegDisplayWidgetClass;

typedef struct _XnvrMpegDisplayClassRec	*XnvrMpegDisplayWidgetClass;
typedef struct _XnvrMpegDisplayRec	*XnvrMpegDisplayWidget;

#endif /* _NvrMpegDisplay_h_ */
