/*
 * Copyright (c) 1992,1993, North Valley Research, Inc.
 * Confidential -- All proprietary rights reserved.
 * Licensed Material -- Property of North Valley Research, Inc.
 *
 * This program is the property of North Valley Research, Inc. or others
 * from whom North Valley Research has obtained a licensing right, and is
 * considered by North Valley Research to be confidential.  It is protected
 * by U.S. copyright law as an unpublished work and is
 * furnished pursuant to a written license agreement.  It may
 * not be used, copied or otherwise reproduced, or disclosed to
 * others except in accordance with the terms and conditions of
 * that agreement.
 *
 * NAME
 *	demoPlayer.c - simple mpeg player
 *
 * DESCRIPTION
 *
 * $Header: /nvr/share/src/nvr/prod/applications/demoPlayer/RCS/demoPlayer.c,v 1.1 1995/12/06 19:55:39 toddb Exp $
 */
#include "NvrMpegDisplay.h"

#include <Xm/Xm.h>
#include <Xm/Form.h>
#include <Xm/AtomMgr.h>
#include <Xm/Protocols.h>
#include <Xm/MwmUtil.h>
#include <Xm/Frame.h>
#include <Xm/Label.h>
#include <Xm/DrawingA.h>


#include <stdio.h>

typedef struct _MplayerInfo {
    Widget topLevel;
    Widget video;
    Boolean started;
} MplayerInfo, *MplayerInfoPtr;

static void
ReallyQuitCB(Widget w, XtPointer unused, XtPointer alsoUnused)
{
    exit(0);
}

static void
SetMpegColormapWindows(Widget topLevel, Widget video)
{
    Window list[2];
    /*
     * We update the list of colormap windows here because
     * the mpeg widget's window may have changed.  We have to
     * use XSetWMColormapWindows() instead of XtSetWMColormapWindows()
     * because the decoder window is not a widget.
     */
    XtVaGetValues(video, XnvrNDecodeWindow, &list[0], NULL);
    list[1] = XtWindow(topLevel);
    XSetWMColormapWindows(XtDisplay(video), XtWindow(topLevel),
			  list, XtNumber(list));
}

static void
MplayerVideoExposeCb(Widget w, XtPointer userData, XtPointer widgetData)
{
    MplayerInfoPtr mplayer = (MplayerInfoPtr)userData;

    if (! mplayer->started) {
	XtVaSetValues(w,
		      XnvrNAction, NvrPlayAll,
		      NULL);
	mplayer->started = False;
    }
}

static void
MplayerVideoPaneCreate(MplayerInfoPtr mplayer)
{
    Widget videoPane;
    Widget videoFrame;

    /*
     * Video Display window
     */
    videoPane = XtVaCreateWidget("mpegVideoPane",
	    xmFormWidgetClass,		mplayer->topLevel,
	    NULL);
    videoFrame = XtVaCreateManagedWidget("videoFrame",
	    xmFrameWidgetClass,		videoPane,
	    XmNtopAttachment,		XmATTACH_FORM,
	    XmNleftAttachment,		XmATTACH_FORM,
	    XmNrightAttachment,		XmATTACH_FORM,
	    XmNshadowType,		XmSHADOW_IN,
	    XmNshadowThickness,		3,
	    /* if you don't turn off traversal, the motif mavigation
	     * mechanism gets stuck trying to traverse to the videoDisplay
	     * which, not being based on XmPrimitive, hasn't the 
	    * capability.
	     */
	    XmNtraversalOn,		False,
	    XmNnavigationType,		XmNONE,
	    NULL);
    mplayer->video =
	XtVaCreateManagedWidget("videoDisplay",
	    xnvrMpegDisplayWidgetClass,	videoFrame,
	    XmNborderWidth,		0,
	    NULL);

    XtAddCallback(mplayer->video, XmNexposeCallback,
		  MplayerVideoExposeCb, (XtPointer)mplayer);

    (void) XtVaCreateManagedWidget("nvrLabel",
	    xmLabelWidgetClass,		videoPane,
	    XmNrightAttachment,		XmATTACH_FORM,
	    XmNtopAttachment,		XmATTACH_WIDGET,
	    XmNtopWidget,		videoFrame,
	    NULL);

    XtManageChild(videoPane);
}

char *ProgramName;

int
main (unsigned int argc, char **argv)
{
    Atom wmDeleteWindow;
    MplayerInfo mplayer;
    int nArgs;
    XtAppContext context;
    NvrInputSpec input;

    ProgramName = argv[0];	/* used internally by NVR libraries */

    mplayer.started = False;
    mplayer.topLevel = XtVaAppInitialize(&context, "DemoMpeg",
			NULL, 0, (int*)&argc, argv, NULL, NULL);

    XtVaSetValues(mplayer.topLevel,
		  XmNallowShellResize, True,
		  XmNnoResize, True,
		  NULL);

    /*
     * Video Display window
     */
    MplayerVideoPaneCreate(&mplayer);

    /* Link window manager close button to quit callback */
    XtVaSetValues(mplayer.topLevel, XmNdeleteResponse, XmDO_NOTHING, NULL);
    wmDeleteWindow = XmInternAtom(XtDisplay(mplayer.topLevel),
				  "WM_DELETE_WINDOW", False);
    XmAddWMProtocolCallback(mplayer.topLevel,
			    wmDeleteWindow, ReallyQuitCB, NULL);

    /* disable resize handles */
    {
	int decor;
	decor = MWM_DECOR_BORDER | MWM_DECOR_TITLE | MWM_DECOR_MENU |
			MWM_DECOR_MAXIMIZE | MWM_DECOR_MINIMIZE;
	XtVaSetValues(mplayer.topLevel, XmNmwmDecorations, decor, NULL);
    }

    nArgs = argc-1;
    if (nArgs == 0) {
	fprintf(stderr, "no input file(s) specified\n");
	exit(0);
    }
    input.single.type = NvrInputSinglePath;
    input.single.path = argv[1];
    XtVaSetValues(mplayer.video, XnvrNInputFile, &input, NULL);

    XtRealizeWidget(mplayer.topLevel);
    SetMpegColormapWindows(mplayer.topLevel, mplayer.video);
    XSync(XtDisplay(mplayer.topLevel), False);

    XtAppMainLoop(context);
    return(0);
}
